==> postgrest-0.5.0.0-34-armv7h.pkg.tar.xz: usr/share/haskell/register/postgrest.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgrest
version: 0.5.0.0
id: postgrest-0.5.0.0-VNsMv2KNhUCMrBC2OtJbZ
key: postgrest-0.5.0.0-VNsMv2KNhUCMrBC2OtJbZ
license: MIT
maintainer: cred+github@begriffs.com
author: Joe Nelson, Adam Baker
homepage: https://github.com/PostgREST/postgrest
synopsis: REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for the tables and views, supporting all HTTP verbs that security
    permits.
category: Web
abi: 048ac66fc417c337c4e6d936dce65d25
exposed: True
exposed-modules:
    PostgREST.ApiRequest PostgREST.App PostgREST.Auth PostgREST.Config
    PostgREST.DbRequestBuilder PostgREST.DbStructure PostgREST.Error
    PostgREST.Middleware PostgREST.OpenAPI PostgREST.Parsers
    PostgREST.QueryBuilder PostgREST.RangeQuery PostgREST.Types
hidden-modules: Paths_postgrest
import-dirs: /usr/lib/ghc-8.4.3/site-local/postgrest-0.5.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/postgrest-0.5.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/postgrest-0.5.0.0
hs-libraries: HSpostgrest-0.5.0.0-VNsMv2KNhUCMrBC2OtJbZ
depends:
    aeson-1.4.1.0-GPUdiNXlyQm9pSbB9CFKk6
    ansi-wl-pprint-0.6.8.2-LQZDE7SKgje91HGB8abfY4 base-4.11.1.0
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    cassava-0.5.1.0-9NrmMM5FEKT1lAT6aG5cO3
    configurator-ng-0.0.0.1-KCxy8sclqCR3I2Gjav5rgG containers-0.5.11.0
    contravariant-1.5-5VBqEYOPGpyDW8QIali4BA
    contravariant-extras-0.3.4-6KPikGErH6JFY1GxYeFsWF
    either-5.0.1-Lufqj3obt7dBrAIR3lD2JZ
    gitrev-1.3.1-I3rV26MPk8fH6eAgYo6ASC
    hasql-1.3.0.3-6AI5T85Qpr2Hq3sDyvkAsH
    hasql-pool-0.5-JtOYCKmWX3ZXFepgiWoiC
    hasql-transaction-0.7-3BY6pZPrHYj4kcxc0g7PCB
    heredoc-0.2.0.0-Aca6RcVoh8MB0pyn5losTR
    HTTP-4000.3.12-6RmfzUhzvsMFoS1ITD5PLw
    http-types-0.12.1-DPH0TPam88TG8PoMMTVrPI
    insert-ordered-containers-0.2.1.0-HP8b7BPbqA8A5SqHypuKJt
    interpolatedstring-perl6-1.0.0-1dCR26QCRd9BF82WamZsn3
    jose-0.7.0.0-BIUE8qI142o8L7CkpPiYr8
    lens-4.17-A5yuSdXdLjmKpBlpOnn6t2
    lens-aeson-1.0.2-BMOJJEsEAYt7YtVSkZOlfB
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    optparse-applicative-0.14.2.0-5kDvpaFLtQNB16vTZLs8dg
    parsec-3.1.13.0 protolude-0.2.2-EOgREkuBhfuIEro3wh4uS3
    Ranged-sets-0.3.0-IVqwPqonijmBiSQsuY7IQL
    regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
    swagger2-2.2.2-GcPOaZrJ1h1tiLVKiAxrg text-1.2.3.0 time-1.8.0.2
    unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    wai-3.2.1.2-LdjnJgyYMiX1AlRBYsp0pc
    wai-cors-0.2.6-Ck7BaIsYC2K1WMgfwiydo0
    wai-extra-3.0.24.2-K1IW9gtMRQp35uXginlj0o
    wai-middleware-static-0.8.2-K3lfJ0oDa6R2UUDRrMeesr
    cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ
abi-depends: aeson-1.4.1.0-GPUdiNXlyQm9pSbB9CFKk6=22145541f26b56c63b48572ec79b9cbd
             ansi-wl-pprint-0.6.8.2-LQZDE7SKgje91HGB8abfY4=d46a34a69558ad25fb56e0bfd9741e31
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             cassava-0.5.1.0-9NrmMM5FEKT1lAT6aG5cO3=b14bd48a0947ff76dd5e44556ff49449
             configurator-ng-0.0.0.1-KCxy8sclqCR3I2Gjav5rgG=97be281702e2d6a69b200a7679fbd5d1
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             contravariant-1.5-5VBqEYOPGpyDW8QIali4BA=02e9ed60b8864056c6af15ff76a262ef
             contravariant-extras-0.3.4-6KPikGErH6JFY1GxYeFsWF=b0320e129fae25e9c4c825b327d6cb2f
             either-5.0.1-Lufqj3obt7dBrAIR3lD2JZ=fe71d09c6b133ebdd33bec6d9cf76120
             gitrev-1.3.1-I3rV26MPk8fH6eAgYo6ASC=dfadfabf13d3d9a6719171042287531b
             hasql-1.3.0.3-6AI5T85Qpr2Hq3sDyvkAsH=761a6eb34d51629aa2722cbefb701267
             hasql-pool-0.5-JtOYCKmWX3ZXFepgiWoiC=0f9e2fe3ed8192fcaf4517b3b5033124
             hasql-transaction-0.7-3BY6pZPrHYj4kcxc0g7PCB=4a945e27446d533983110d51e8b5cd66
             heredoc-0.2.0.0-Aca6RcVoh8MB0pyn5losTR=b190746a16f282487a662da19c44cf13
             HTTP-4000.3.12-6RmfzUhzvsMFoS1ITD5PLw=bd1e10230bc3904877df6d9f651003b9
             http-types-0.12.1-DPH0TPam88TG8PoMMTVrPI=5812fc30bee4238b84269137c786fffe
             insert-ordered-containers-0.2.1.0-HP8b7BPbqA8A5SqHypuKJt=ad28643c77999f6a2d5d7ba471295834
             interpolatedstring-perl6-1.0.0-1dCR26QCRd9BF82WamZsn3=2106ecebab43444e935d8c187af589d5
             jose-0.7.0.0-BIUE8qI142o8L7CkpPiYr8=0085a9017ac346dc37221bbf85bb6d31
             lens-4.17-A5yuSdXdLjmKpBlpOnn6t2=4637bd44a39b4c072a280c87c676b7c9
             lens-aeson-1.0.2-BMOJJEsEAYt7YtVSkZOlfB=6fa5342d0c12e34098f2885e9c85b4b8
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
             optparse-applicative-0.14.2.0-5kDvpaFLtQNB16vTZLs8dg=ae7f0ef22284c6d85efc629be435c88e
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             protolude-0.2.2-EOgREkuBhfuIEro3wh4uS3=18ed455f1a139902a7939fe781363764
             Ranged-sets-0.3.0-IVqwPqonijmBiSQsuY7IQL=9fb8fc4b1711a19c280f975a4fa4bd83
             regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K=98feb6ae4c5e833326f77c1995f4743b
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             swagger2-2.2.2-GcPOaZrJ1h1tiLVKiAxrg=f7b384e193d466c23a3ff74dc87c0fac
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre=264f905ec4c04eb05b5ff3d7321fae90
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             wai-3.2.1.2-LdjnJgyYMiX1AlRBYsp0pc=61f19326830628d9a1cd674a106240fe
             wai-cors-0.2.6-Ck7BaIsYC2K1WMgfwiydo0=5ef78fde930d1e4c405fd5b739b52f26
             wai-extra-3.0.24.2-K1IW9gtMRQp35uXginlj0o=d37e0c84f91aac2dd55222eddccfde6a
             wai-middleware-static-0.8.2-K3lfJ0oDa6R2UUDRrMeesr=5c5d9cf5d4b9a11a9555fc8f20e97232
             cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ=98943a44942d0f9eb24e49aaa7774a37
haddock-interfaces: /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html: /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> postgrest-0.5.0.0-37-armv7h.pkg.tar.xz: usr/share/haskell/register/postgrest.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgrest
version: 0.5.0.0
id: postgrest-0.5.0.0-DySwRt02PwB6GVIxGefAvf
key: postgrest-0.5.0.0-DySwRt02PwB6GVIxGefAvf
license: MIT
maintainer: cred+github@begriffs.com
author: Joe Nelson, Adam Baker
homepage: https://github.com/PostgREST/postgrest
synopsis: REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for the tables and views, supporting all HTTP verbs that security
    permits.
category: Web
abi: 7f2221043e7865e16fd6093c22032056
exposed: True
exposed-modules:
    PostgREST.ApiRequest PostgREST.App PostgREST.Auth PostgREST.Config
    PostgREST.DbRequestBuilder PostgREST.DbStructure PostgREST.Error
    PostgREST.Middleware PostgREST.OpenAPI PostgREST.Parsers
    PostgREST.QueryBuilder PostgREST.RangeQuery PostgREST.Types
hidden-modules: Paths_postgrest
import-dirs: /usr/lib/ghc-8.4.3/site-local/postgrest-0.5.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/postgrest-0.5.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/postgrest-0.5.0.0
hs-libraries: HSpostgrest-0.5.0.0-DySwRt02PwB6GVIxGefAvf
depends:
    aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX
    ansi-wl-pprint-0.6.8.2-LQZDE7SKgje91HGB8abfY4 base-4.11.1.0
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    cassava-0.5.1.0-KPZW93IsQUUG6MKnUd7IJJ
    configurator-ng-0.0.0.1-KCxy8sclqCR3I2Gjav5rgG containers-0.5.11.0
    contravariant-1.5-5VBqEYOPGpyDW8QIali4BA
    contravariant-extras-0.3.4-6KPikGErH6JFY1GxYeFsWF
    either-5.0.1-Lufqj3obt7dBrAIR3lD2JZ
    gitrev-1.3.1-I3rV26MPk8fH6eAgYo6ASC
    hasql-1.3.0.3-A28fv0W4zWzEGbSWvADfsi
    hasql-pool-0.5-EDnO6U3VeK22K9C1GsZpc0
    hasql-transaction-0.7-2GtMVUT2s2vGgpjlv4sVGz
    heredoc-0.2.0.0-Aca6RcVoh8MB0pyn5losTR
    HTTP-4000.3.12-2isb0112H3JBlfCj4locoJ
    http-types-0.12.1-4vnZYSvdyyi5YD2kTvZyqz
    insert-ordered-containers-0.2.1.0-HJWwLNnWr0LAjw4h7sFqnK
    interpolatedstring-perl6-1.0.0-7qm1nKrZaeXLmRarfcCNOU
    jose-0.7.0.0-5zhkvRqL2UmJ9ItTIJ6wEG
    lens-4.17-A5yuSdXdLjmKpBlpOnn6t2
    lens-aeson-1.0.2-6wLXvYD8QzDDIFuxqTFrN2
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    optparse-applicative-0.14.2.0-5kDvpaFLtQNB16vTZLs8dg
    parsec-3.1.13.0 protolude-0.2.2-EOgREkuBhfuIEro3wh4uS3
    Ranged-sets-0.3.0-IVqwPqonijmBiSQsuY7IQL
    regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
    swagger2-2.2.2-3FHs6FcB2hL2WmBGBbUWIp text-1.2.3.0 time-1.8.0.2
    unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    wai-3.2.1.2-C1NXINF5Asz4Xltxrsh4qv
    wai-cors-0.2.6-4AA2Ufxe5O45PeRIqLtwNH
    wai-extra-3.0.24.2-BM6iBMMkeixC6AN480902r
    wai-middleware-static-0.8.2-Gsw5vhDQRfKLd7lpbJoI8m
    cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ
abi-depends: aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX=25adaf2f506e44c8d5bd8da34f9279d5
             ansi-wl-pprint-0.6.8.2-LQZDE7SKgje91HGB8abfY4=d46a34a69558ad25fb56e0bfd9741e31
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             cassava-0.5.1.0-KPZW93IsQUUG6MKnUd7IJJ=fd559c5e6d80f3933cb1f29229a52b8f
             configurator-ng-0.0.0.1-KCxy8sclqCR3I2Gjav5rgG=97be281702e2d6a69b200a7679fbd5d1
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             contravariant-1.5-5VBqEYOPGpyDW8QIali4BA=02e9ed60b8864056c6af15ff76a262ef
             contravariant-extras-0.3.4-6KPikGErH6JFY1GxYeFsWF=b0320e129fae25e9c4c825b327d6cb2f
             either-5.0.1-Lufqj3obt7dBrAIR3lD2JZ=fe71d09c6b133ebdd33bec6d9cf76120
             gitrev-1.3.1-I3rV26MPk8fH6eAgYo6ASC=dfadfabf13d3d9a6719171042287531b
             hasql-1.3.0.3-A28fv0W4zWzEGbSWvADfsi=e5f6a653775305a390983e127c6cfc9b
             hasql-pool-0.5-EDnO6U3VeK22K9C1GsZpc0=939206d6d0b742f33d539748d8ae6b66
             hasql-transaction-0.7-2GtMVUT2s2vGgpjlv4sVGz=6c38e8e026c4a4536ddfe462edc39b59
             heredoc-0.2.0.0-Aca6RcVoh8MB0pyn5losTR=b190746a16f282487a662da19c44cf13
             HTTP-4000.3.12-2isb0112H3JBlfCj4locoJ=ced794015c77cbf0096fd84ac1c4dcfc
             http-types-0.12.1-4vnZYSvdyyi5YD2kTvZyqz=83a424f80f062f589a336c1b654188f8
             insert-ordered-containers-0.2.1.0-HJWwLNnWr0LAjw4h7sFqnK=424350acfad5e35a193d8b093e902027
             interpolatedstring-perl6-1.0.0-7qm1nKrZaeXLmRarfcCNOU=8c6efea56526c7a17a5c3350a582a064
             jose-0.7.0.0-5zhkvRqL2UmJ9ItTIJ6wEG=6cb0b203d5bd885d19a7e1923a55a999
             lens-4.17-A5yuSdXdLjmKpBlpOnn6t2=4637bd44a39b4c072a280c87c676b7c9
             lens-aeson-1.0.2-6wLXvYD8QzDDIFuxqTFrN2=124862ced19db63da26f91a3907e7578
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
             optparse-applicative-0.14.2.0-5kDvpaFLtQNB16vTZLs8dg=ae7f0ef22284c6d85efc629be435c88e
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             protolude-0.2.2-EOgREkuBhfuIEro3wh4uS3=18ed455f1a139902a7939fe781363764
             Ranged-sets-0.3.0-IVqwPqonijmBiSQsuY7IQL=9fb8fc4b1711a19c280f975a4fa4bd83
             regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K=98feb6ae4c5e833326f77c1995f4743b
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             swagger2-2.2.2-3FHs6FcB2hL2WmBGBbUWIp=4d6cd3cf8a3773e26321c61cd946fd02
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre=264f905ec4c04eb05b5ff3d7321fae90
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             wai-3.2.1.2-C1NXINF5Asz4Xltxrsh4qv=c78051ce3bf4822fdb7b0e21c322f844
             wai-cors-0.2.6-4AA2Ufxe5O45PeRIqLtwNH=8e3159a913d636ffe5bf244491f63a23
             wai-extra-3.0.24.2-BM6iBMMkeixC6AN480902r=4464d0d2f40ace555ed3e7a41eec9445
             wai-middleware-static-0.8.2-Gsw5vhDQRfKLd7lpbJoI8m=46ea9c7224b40ad34f25b4d2aa25a286
             cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ=98943a44942d0f9eb24e49aaa7774a37
haddock-interfaces: /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html: /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
